==> marginaleffects_0.4.1.tar.gz: marginaleffects/tests/testthat/test-plot_cap.R <==
skip_if(getRversion() < "4.1.0") # different graphics engines
skip_on_cran() # different graphics engine produce different snapshots

test_that("two conditions", {
    mod <- lm(mpg ~ hp * wt * am, data = mtcars)
    p <- plot_cap(mod, condition = c("hp", "wt"))
    vdiffr::expect_doppelganger("cmm plot with 2 conditions", p)
})

test_that("continuous vs. categorical x-axis", {
    mod <- lm(mpg ~ hp * wt * factor(cyl), mtcars)
    p <- plot_cap(mod, condition = c("cyl", "wt"))
    vdiffr::expect_doppelganger("cmm categorical x-axis", p)
    p <- plot_cap(mod, condition = c("wt", "cyl"))
    vdiffr::expect_doppelganger("cmm continuous x-axis", p)
})

test_that("conf.level in plots", {
    mod <- lm(mpg ~ hp * wt * am, data = mtcars)
    p1 <- plot_cap(mod, condition = "hp", conf.level = .99)
    p2 <- plot_cap(mod, condition = "hp", conf.level = .4)
    vdiffr::expect_doppelganger("plot_cap large ci", p1)
    vdiffr::expect_doppelganger("plot_cap small ci", p2)
})

test_that("link vs response", {
    mod <- glm(am ~ hp + wt, data = mtcars, family = binomial)
    p1 <- plot_cap(mod, condition = "hp", type = "response")
    p2 <- plot_cap(mod, condition = "hp", type = "link")
    vdiffr::expect_doppelganger("plot_cap logit response", p1)
    vdiffr::expect_doppelganger("plot_cap logit link", p2)
})

test_that("bad condition raises error", {
    mod <- lm(mpg ~ hp * wt * am, data = mtcars)
    expect_error(plot_cap(mod, condition = c("bad", "wt")))
})

test_that("Issue #230: glm w/ weights includes confidence intervals", {
    mod <- glm(am ~ mpg * cyl, data = mtcars, family = binomial(link = "logit"), weights = carb)
    p <- plot_cap(mod, condition = c("mpg", "cyl"), draw = FALSE)
    expect_true("conf.low" %in% colnames(p))
    expect_true("conf.high" %in% colnames(p))
})

==> marginaleffects_0.5.0.tar.gz: marginaleffects/tests/testthat/test-plot_cap.R <==
skip_if(getRversion() < "4.1.0") # different graphics engines
skip_on_cran() # different graphics engine produce different snapshots

test_that("two conditions", {
    mod <- lm(mpg ~ hp * wt * am, data = mtcars)
    p <- plot_cap(mod, condition = c("hp", "wt"))
    vdiffr::expect_doppelganger("cmm plot with 2 conditions", p)
})

test_that("continuous vs. categorical x-axis", {
    mod <- lm(mpg ~ hp * wt * factor(cyl), mtcars)
    p <- plot_cap(mod, condition = c("cyl", "wt"))
    vdiffr::expect_doppelganger("cmm categorical x-axis", p)
    p <- plot_cap(mod, condition = c("wt", "cyl"))
    vdiffr::expect_doppelganger("cmm continuous x-axis", p)
})

test_that("conf.level in plots", {
    mod <- lm(mpg ~ hp * wt * am, data = mtcars)
    p1 <- plot_cap(mod, condition = "hp", conf.level = .99)
    p2 <- plot_cap(mod, condition = "hp", conf.level = .4)
    vdiffr::expect_doppelganger("plot_cap large ci", p1)
    vdiffr::expect_doppelganger("plot_cap small ci", p2)
})

test_that("link vs response", {
    mod <- glm(am ~ hp + wt, data = mtcars, family = binomial)
    p1 <- plot_cap(mod, condition = "hp", type = "response")
    p2 <- plot_cap(mod, condition = "hp", type = "link")
    vdiffr::expect_doppelganger("plot_cap logit response", p1)
    vdiffr::expect_doppelganger("plot_cap logit link", p2)
})

test_that("bad condition raises error", {
    mod <- lm(mpg ~ hp * wt * am, data = mtcars)
    expect_error(plot_cap(mod, condition = c("bad", "wt")))
})

test_that("Issue #230: glm w/ weights includes confidence intervals", {
    mod <- glm(am ~ mpg * cyl, data = mtcars, family = binomial(link = "logit"), weights = carb)
    p <- plot_cap(mod, condition = c("mpg", "cyl"), draw = FALSE)
    expect_true("conf.low" %in% colnames(p))
    expect_true("conf.high" %in% colnames(p))
})


test_that("vcov", {
    skip_if_not_installed("insight", minimum_version = "0.17.1")
    mod <- lm(mpg ~ hp * wt, data = mtcars)
    mfx0 <- plot_cap(mod, condition = "wt", vcov = FALSE, draw = FALSE)
    mfx1 <- plot_cap(mod, condition = "wt", draw = FALSE)
    mfx2 <- plot_cap(mod, condition = "wt", vcov = "HC3", draw = FALSE)
    mfx3 <- plot_cap(mod, condition = "wt", vcov = ~cyl, draw = FALSE)
    expect_false("conf.low" %in% colnames(mfx0))
    expect_true(all(mfx1$std.error != mfx2$std.error))
    expect_true(all(mfx1$std.error != mfx3$std.error))
    expect_true(all(mfx2$std.error != mfx3$std.error))
    expect_true(all(mfx1$conf.low != mfx2$conf.low))
    expect_true(all(mfx1$conf.low != mfx3$conf.low))
    expect_true(all(mfx2$conf.low != mfx3$conf.low))
})
